This is the mail archive of the gdb-patches@sourceware.org mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[PATCH] Update comments to list_args_or_locals.


The comments to function list_args_or_locals look out of date.  This
patch is to update the comments.  I am not good at writing comments,
so review is required here, IMO.

gdb:

2013-08-05  Yao Qi  <yao@codesourcery.com>

	* mi/mi-cmd-stack.c: Update comments to function
	list_args_or_locals.
---
 gdb/mi/mi-cmd-stack.c |    7 +++----
 1 files changed, 3 insertions(+), 4 deletions(-)

diff --git a/gdb/mi/mi-cmd-stack.c b/gdb/mi/mi-cmd-stack.c
index 70ff0b6..416f0f4 100644
--- a/gdb/mi/mi-cmd-stack.c
+++ b/gdb/mi/mi-cmd-stack.c
@@ -502,10 +502,9 @@ list_arg_or_local (const struct frame_arg *arg, enum what_to_list what,
   do_cleanups (old_chain);
 }
 
-/* Print a list of the locals or the arguments for the currently
-   selected frame.  If the argument passed is 0, printonly the names
-   of the variables, if an argument of 1 is passed, print the values
-   as well.  */
+/* Print a list of the objects for the currently selected frame FI in
+   a certain form, which is determined by VALUES.  The objects can be
+   locals, arguments or both, which is determined by WHAT.  */
 
 static void
 list_args_or_locals (enum what_to_list what, enum print_values values,
-- 
1.7.7.6


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]